# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ModelServingProvisionedThroughputArgs', 'ModelServingProvisionedThroughput']

@pulumi.input_type
class ModelServingProvisionedThroughputArgs:
    def __init__(__self__, *,
                 config: pulumi.Input['ModelServingProvisionedThroughputConfigArgs'],
                 ai_gateway: Optional[pulumi.Input['ModelServingProvisionedThroughputAiGatewayArgs']] = None,
                 budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 email_notifications: Optional[pulumi.Input['ModelServingProvisionedThroughputEmailNotificationsArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['ModelServingProvisionedThroughputProviderConfigArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ModelServingProvisionedThroughputTagArgs']]]] = None):
        """
        The set of arguments for constructing a ModelServingProvisionedThroughput resource.
        :param pulumi.Input['ModelServingProvisionedThroughputConfigArgs'] config: The model serving endpoint configuration.
        :param pulumi.Input['ModelServingProvisionedThroughputAiGatewayArgs'] ai_gateway: A block with AI Gateway configuration for the serving endpoint. *Note: only external model endpoints are supported as of now.*
        :param pulumi.Input[_builtins.str] budget_policy_id: The Budget Policy ID set for this serving endpoint.
        :param pulumi.Input['ModelServingProvisionedThroughputEmailNotificationsArgs'] email_notifications: A block with Email notification setting.
        :param pulumi.Input[_builtins.str] name: The name of the model serving endpoint. This field is required and must be unique across a workspace. An endpoint name can consist of alphanumeric characters, dashes, and underscores. NOTE: Changing this name will delete the existing endpoint and create a new endpoint with the updated name.
        :param pulumi.Input['ModelServingProvisionedThroughputProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[Sequence[pulumi.Input['ModelServingProvisionedThroughputTagArgs']]] tags: Tags to be attached to the serving endpoint and automatically propagated to billing logs.
        """
        pulumi.set(__self__, "config", config)
        if ai_gateway is not None:
            pulumi.set(__self__, "ai_gateway", ai_gateway)
        if budget_policy_id is not None:
            pulumi.set(__self__, "budget_policy_id", budget_policy_id)
        if email_notifications is not None:
            pulumi.set(__self__, "email_notifications", email_notifications)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def config(self) -> pulumi.Input['ModelServingProvisionedThroughputConfigArgs']:
        """
        The model serving endpoint configuration.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: pulumi.Input['ModelServingProvisionedThroughputConfigArgs']):
        pulumi.set(self, "config", value)

    @_builtins.property
    @pulumi.getter(name="aiGateway")
    def ai_gateway(self) -> Optional[pulumi.Input['ModelServingProvisionedThroughputAiGatewayArgs']]:
        """
        A block with AI Gateway configuration for the serving endpoint. *Note: only external model endpoints are supported as of now.*
        """
        return pulumi.get(self, "ai_gateway")

    @ai_gateway.setter
    def ai_gateway(self, value: Optional[pulumi.Input['ModelServingProvisionedThroughputAiGatewayArgs']]):
        pulumi.set(self, "ai_gateway", value)

    @_builtins.property
    @pulumi.getter(name="budgetPolicyId")
    def budget_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Budget Policy ID set for this serving endpoint.
        """
        return pulumi.get(self, "budget_policy_id")

    @budget_policy_id.setter
    def budget_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "budget_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="emailNotifications")
    def email_notifications(self) -> Optional[pulumi.Input['ModelServingProvisionedThroughputEmailNotificationsArgs']]:
        """
        A block with Email notification setting.
        """
        return pulumi.get(self, "email_notifications")

    @email_notifications.setter
    def email_notifications(self, value: Optional[pulumi.Input['ModelServingProvisionedThroughputEmailNotificationsArgs']]):
        pulumi.set(self, "email_notifications", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the model serving endpoint. This field is required and must be unique across a workspace. An endpoint name can consist of alphanumeric characters, dashes, and underscores. NOTE: Changing this name will delete the existing endpoint and create a new endpoint with the updated name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['ModelServingProvisionedThroughputProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['ModelServingProvisionedThroughputProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ModelServingProvisionedThroughputTagArgs']]]]:
        """
        Tags to be attached to the serving endpoint and automatically propagated to billing logs.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ModelServingProvisionedThroughputTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ModelServingProvisionedThroughputState:
    def __init__(__self__, *,
                 ai_gateway: Optional[pulumi.Input['ModelServingProvisionedThroughputAiGatewayArgs']] = None,
                 budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 config: Optional[pulumi.Input['ModelServingProvisionedThroughputConfigArgs']] = None,
                 email_notifications: Optional[pulumi.Input['ModelServingProvisionedThroughputEmailNotificationsArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['ModelServingProvisionedThroughputProviderConfigArgs']] = None,
                 serving_endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ModelServingProvisionedThroughputTagArgs']]]] = None):
        """
        Input properties used for looking up and filtering ModelServingProvisionedThroughput resources.
        :param pulumi.Input['ModelServingProvisionedThroughputAiGatewayArgs'] ai_gateway: A block with AI Gateway configuration for the serving endpoint. *Note: only external model endpoints are supported as of now.*
        :param pulumi.Input[_builtins.str] budget_policy_id: The Budget Policy ID set for this serving endpoint.
        :param pulumi.Input['ModelServingProvisionedThroughputConfigArgs'] config: The model serving endpoint configuration.
        :param pulumi.Input['ModelServingProvisionedThroughputEmailNotificationsArgs'] email_notifications: A block with Email notification setting.
        :param pulumi.Input[_builtins.str] name: The name of the model serving endpoint. This field is required and must be unique across a workspace. An endpoint name can consist of alphanumeric characters, dashes, and underscores. NOTE: Changing this name will delete the existing endpoint and create a new endpoint with the updated name.
        :param pulumi.Input['ModelServingProvisionedThroughputProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] serving_endpoint_id: Unique identifier of the serving endpoint primarily used to set permissions and refer to this instance for other operations.
        :param pulumi.Input[Sequence[pulumi.Input['ModelServingProvisionedThroughputTagArgs']]] tags: Tags to be attached to the serving endpoint and automatically propagated to billing logs.
        """
        if ai_gateway is not None:
            pulumi.set(__self__, "ai_gateway", ai_gateway)
        if budget_policy_id is not None:
            pulumi.set(__self__, "budget_policy_id", budget_policy_id)
        if config is not None:
            pulumi.set(__self__, "config", config)
        if email_notifications is not None:
            pulumi.set(__self__, "email_notifications", email_notifications)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if serving_endpoint_id is not None:
            pulumi.set(__self__, "serving_endpoint_id", serving_endpoint_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="aiGateway")
    def ai_gateway(self) -> Optional[pulumi.Input['ModelServingProvisionedThroughputAiGatewayArgs']]:
        """
        A block with AI Gateway configuration for the serving endpoint. *Note: only external model endpoints are supported as of now.*
        """
        return pulumi.get(self, "ai_gateway")

    @ai_gateway.setter
    def ai_gateway(self, value: Optional[pulumi.Input['ModelServingProvisionedThroughputAiGatewayArgs']]):
        pulumi.set(self, "ai_gateway", value)

    @_builtins.property
    @pulumi.getter(name="budgetPolicyId")
    def budget_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Budget Policy ID set for this serving endpoint.
        """
        return pulumi.get(self, "budget_policy_id")

    @budget_policy_id.setter
    def budget_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "budget_policy_id", value)

    @_builtins.property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input['ModelServingProvisionedThroughputConfigArgs']]:
        """
        The model serving endpoint configuration.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input['ModelServingProvisionedThroughputConfigArgs']]):
        pulumi.set(self, "config", value)

    @_builtins.property
    @pulumi.getter(name="emailNotifications")
    def email_notifications(self) -> Optional[pulumi.Input['ModelServingProvisionedThroughputEmailNotificationsArgs']]:
        """
        A block with Email notification setting.
        """
        return pulumi.get(self, "email_notifications")

    @email_notifications.setter
    def email_notifications(self, value: Optional[pulumi.Input['ModelServingProvisionedThroughputEmailNotificationsArgs']]):
        pulumi.set(self, "email_notifications", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the model serving endpoint. This field is required and must be unique across a workspace. An endpoint name can consist of alphanumeric characters, dashes, and underscores. NOTE: Changing this name will delete the existing endpoint and create a new endpoint with the updated name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['ModelServingProvisionedThroughputProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['ModelServingProvisionedThroughputProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="servingEndpointId")
    def serving_endpoint_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the serving endpoint primarily used to set permissions and refer to this instance for other operations.
        """
        return pulumi.get(self, "serving_endpoint_id")

    @serving_endpoint_id.setter
    def serving_endpoint_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "serving_endpoint_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ModelServingProvisionedThroughputTagArgs']]]]:
        """
        Tags to be attached to the serving endpoint and automatically propagated to billing logs.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ModelServingProvisionedThroughputTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("databricks:index/modelServingProvisionedThroughput:ModelServingProvisionedThroughput")
class ModelServingProvisionedThroughput(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ai_gateway: Optional[pulumi.Input[Union['ModelServingProvisionedThroughputAiGatewayArgs', 'ModelServingProvisionedThroughputAiGatewayArgsDict']]] = None,
                 budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 config: Optional[pulumi.Input[Union['ModelServingProvisionedThroughputConfigArgs', 'ModelServingProvisionedThroughputConfigArgsDict']]] = None,
                 email_notifications: Optional[pulumi.Input[Union['ModelServingProvisionedThroughputEmailNotificationsArgs', 'ModelServingProvisionedThroughputEmailNotificationsArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['ModelServingProvisionedThroughputProviderConfigArgs', 'ModelServingProvisionedThroughputProviderConfigArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ModelServingProvisionedThroughputTagArgs', 'ModelServingProvisionedThroughputTagArgsDict']]]]] = None,
                 __props__=None):
        """
        This resource allows you to manage [Foundation Model provisioned throughput](https://docs.databricks.com/aws/en/machine-learning/foundation-model-apis/deploy-prov-throughput-foundation-model-apis) endpoints in Databricks.

        > This resource is currently in private preview, and only available for enrolled customers.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        Creating a Foundation Model provisioned throughput endpoint

        ```python
        import pulumi
        import pulumi_databricks as databricks

        llama = databricks.ModelServingProvisionedThroughput("llama",
            ai_gateway={
                "usage_tracking_config": {
                    "enabled": True,
                },
            },
            config={
                "served_entities": [{
                    "entity_name": "system.ai.llama-4-maverick",
                    "entity_version": "1",
                    "provisioned_model_units": 100,
                }],
            })
        ```

        ## Access Control

        * Permissions can control which groups or individual users can *Manage*, *Query* or *View* individual serving endpoints.

        ## Related Resources

        The following resources are often used in the same context:

        * ModelServing to create custom and external serving endpoints in Databricks.
        * RegisteredModel to create [Models in Unity Catalog](https://docs.databricks.com/en/mlflow/models-in-uc.html) in Databricks.
        * End to end workspace management guide.
        * Directory to manage directories in [Databricks Workspace](https://docs.databricks.com/workspace/workspace-objects.html).
        * MlflowModel to create models in the [workspace model registry](https://docs.databricks.com/en/mlflow/model-registry.html) in Databricks.
        * Notebook to manage [Databricks Notebooks](https://docs.databricks.com/notebooks/index.html).
        * Notebook data to export a notebook from Databricks Workspace.
        * Repo to manage [Databricks Repos](https://docs.databricks.com/repos.html).

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ModelServingProvisionedThroughputAiGatewayArgs', 'ModelServingProvisionedThroughputAiGatewayArgsDict']] ai_gateway: A block with AI Gateway configuration for the serving endpoint. *Note: only external model endpoints are supported as of now.*
        :param pulumi.Input[_builtins.str] budget_policy_id: The Budget Policy ID set for this serving endpoint.
        :param pulumi.Input[Union['ModelServingProvisionedThroughputConfigArgs', 'ModelServingProvisionedThroughputConfigArgsDict']] config: The model serving endpoint configuration.
        :param pulumi.Input[Union['ModelServingProvisionedThroughputEmailNotificationsArgs', 'ModelServingProvisionedThroughputEmailNotificationsArgsDict']] email_notifications: A block with Email notification setting.
        :param pulumi.Input[_builtins.str] name: The name of the model serving endpoint. This field is required and must be unique across a workspace. An endpoint name can consist of alphanumeric characters, dashes, and underscores. NOTE: Changing this name will delete the existing endpoint and create a new endpoint with the updated name.
        :param pulumi.Input[Union['ModelServingProvisionedThroughputProviderConfigArgs', 'ModelServingProvisionedThroughputProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[Sequence[pulumi.Input[Union['ModelServingProvisionedThroughputTagArgs', 'ModelServingProvisionedThroughputTagArgsDict']]]] tags: Tags to be attached to the serving endpoint and automatically propagated to billing logs.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ModelServingProvisionedThroughputArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to manage [Foundation Model provisioned throughput](https://docs.databricks.com/aws/en/machine-learning/foundation-model-apis/deploy-prov-throughput-foundation-model-apis) endpoints in Databricks.

        > This resource is currently in private preview, and only available for enrolled customers.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        Creating a Foundation Model provisioned throughput endpoint

        ```python
        import pulumi
        import pulumi_databricks as databricks

        llama = databricks.ModelServingProvisionedThroughput("llama",
            ai_gateway={
                "usage_tracking_config": {
                    "enabled": True,
                },
            },
            config={
                "served_entities": [{
                    "entity_name": "system.ai.llama-4-maverick",
                    "entity_version": "1",
                    "provisioned_model_units": 100,
                }],
            })
        ```

        ## Access Control

        * Permissions can control which groups or individual users can *Manage*, *Query* or *View* individual serving endpoints.

        ## Related Resources

        The following resources are often used in the same context:

        * ModelServing to create custom and external serving endpoints in Databricks.
        * RegisteredModel to create [Models in Unity Catalog](https://docs.databricks.com/en/mlflow/models-in-uc.html) in Databricks.
        * End to end workspace management guide.
        * Directory to manage directories in [Databricks Workspace](https://docs.databricks.com/workspace/workspace-objects.html).
        * MlflowModel to create models in the [workspace model registry](https://docs.databricks.com/en/mlflow/model-registry.html) in Databricks.
        * Notebook to manage [Databricks Notebooks](https://docs.databricks.com/notebooks/index.html).
        * Notebook data to export a notebook from Databricks Workspace.
        * Repo to manage [Databricks Repos](https://docs.databricks.com/repos.html).

        :param str resource_name: The name of the resource.
        :param ModelServingProvisionedThroughputArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ModelServingProvisionedThroughputArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ai_gateway: Optional[pulumi.Input[Union['ModelServingProvisionedThroughputAiGatewayArgs', 'ModelServingProvisionedThroughputAiGatewayArgsDict']]] = None,
                 budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 config: Optional[pulumi.Input[Union['ModelServingProvisionedThroughputConfigArgs', 'ModelServingProvisionedThroughputConfigArgsDict']]] = None,
                 email_notifications: Optional[pulumi.Input[Union['ModelServingProvisionedThroughputEmailNotificationsArgs', 'ModelServingProvisionedThroughputEmailNotificationsArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['ModelServingProvisionedThroughputProviderConfigArgs', 'ModelServingProvisionedThroughputProviderConfigArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ModelServingProvisionedThroughputTagArgs', 'ModelServingProvisionedThroughputTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ModelServingProvisionedThroughputArgs.__new__(ModelServingProvisionedThroughputArgs)

            __props__.__dict__["ai_gateway"] = ai_gateway
            __props__.__dict__["budget_policy_id"] = budget_policy_id
            if config is None and not opts.urn:
                raise TypeError("Missing required property 'config'")
            __props__.__dict__["config"] = config
            __props__.__dict__["email_notifications"] = email_notifications
            __props__.__dict__["name"] = name
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["tags"] = tags
            __props__.__dict__["serving_endpoint_id"] = None
        super(ModelServingProvisionedThroughput, __self__).__init__(
            'databricks:index/modelServingProvisionedThroughput:ModelServingProvisionedThroughput',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ai_gateway: Optional[pulumi.Input[Union['ModelServingProvisionedThroughputAiGatewayArgs', 'ModelServingProvisionedThroughputAiGatewayArgsDict']]] = None,
            budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            config: Optional[pulumi.Input[Union['ModelServingProvisionedThroughputConfigArgs', 'ModelServingProvisionedThroughputConfigArgsDict']]] = None,
            email_notifications: Optional[pulumi.Input[Union['ModelServingProvisionedThroughputEmailNotificationsArgs', 'ModelServingProvisionedThroughputEmailNotificationsArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['ModelServingProvisionedThroughputProviderConfigArgs', 'ModelServingProvisionedThroughputProviderConfigArgsDict']]] = None,
            serving_endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ModelServingProvisionedThroughputTagArgs', 'ModelServingProvisionedThroughputTagArgsDict']]]]] = None) -> 'ModelServingProvisionedThroughput':
        """
        Get an existing ModelServingProvisionedThroughput resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ModelServingProvisionedThroughputAiGatewayArgs', 'ModelServingProvisionedThroughputAiGatewayArgsDict']] ai_gateway: A block with AI Gateway configuration for the serving endpoint. *Note: only external model endpoints are supported as of now.*
        :param pulumi.Input[_builtins.str] budget_policy_id: The Budget Policy ID set for this serving endpoint.
        :param pulumi.Input[Union['ModelServingProvisionedThroughputConfigArgs', 'ModelServingProvisionedThroughputConfigArgsDict']] config: The model serving endpoint configuration.
        :param pulumi.Input[Union['ModelServingProvisionedThroughputEmailNotificationsArgs', 'ModelServingProvisionedThroughputEmailNotificationsArgsDict']] email_notifications: A block with Email notification setting.
        :param pulumi.Input[_builtins.str] name: The name of the model serving endpoint. This field is required and must be unique across a workspace. An endpoint name can consist of alphanumeric characters, dashes, and underscores. NOTE: Changing this name will delete the existing endpoint and create a new endpoint with the updated name.
        :param pulumi.Input[Union['ModelServingProvisionedThroughputProviderConfigArgs', 'ModelServingProvisionedThroughputProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] serving_endpoint_id: Unique identifier of the serving endpoint primarily used to set permissions and refer to this instance for other operations.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ModelServingProvisionedThroughputTagArgs', 'ModelServingProvisionedThroughputTagArgsDict']]]] tags: Tags to be attached to the serving endpoint and automatically propagated to billing logs.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ModelServingProvisionedThroughputState.__new__(_ModelServingProvisionedThroughputState)

        __props__.__dict__["ai_gateway"] = ai_gateway
        __props__.__dict__["budget_policy_id"] = budget_policy_id
        __props__.__dict__["config"] = config
        __props__.__dict__["email_notifications"] = email_notifications
        __props__.__dict__["name"] = name
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["serving_endpoint_id"] = serving_endpoint_id
        __props__.__dict__["tags"] = tags
        return ModelServingProvisionedThroughput(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="aiGateway")
    def ai_gateway(self) -> pulumi.Output[Optional['outputs.ModelServingProvisionedThroughputAiGateway']]:
        """
        A block with AI Gateway configuration for the serving endpoint. *Note: only external model endpoints are supported as of now.*
        """
        return pulumi.get(self, "ai_gateway")

    @_builtins.property
    @pulumi.getter(name="budgetPolicyId")
    def budget_policy_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The Budget Policy ID set for this serving endpoint.
        """
        return pulumi.get(self, "budget_policy_id")

    @_builtins.property
    @pulumi.getter
    def config(self) -> pulumi.Output['outputs.ModelServingProvisionedThroughputConfig']:
        """
        The model serving endpoint configuration.
        """
        return pulumi.get(self, "config")

    @_builtins.property
    @pulumi.getter(name="emailNotifications")
    def email_notifications(self) -> pulumi.Output[Optional['outputs.ModelServingProvisionedThroughputEmailNotifications']]:
        """
        A block with Email notification setting.
        """
        return pulumi.get(self, "email_notifications")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the model serving endpoint. This field is required and must be unique across a workspace. An endpoint name can consist of alphanumeric characters, dashes, and underscores. NOTE: Changing this name will delete the existing endpoint and create a new endpoint with the updated name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.ModelServingProvisionedThroughputProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="servingEndpointId")
    def serving_endpoint_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the serving endpoint primarily used to set permissions and refer to this instance for other operations.
        """
        return pulumi.get(self, "serving_endpoint_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence['outputs.ModelServingProvisionedThroughputTag']]]:
        """
        Tags to be attached to the serving endpoint and automatically propagated to billing logs.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WorkspaceSettingV2Args', 'WorkspaceSettingV2']

@pulumi.input_type
class WorkspaceSettingV2Args:
    def __init__(__self__, *,
                 aibi_dashboard_embedding_access_policy: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs']] = None,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs']] = None,
                 automatic_cluster_update_workspace: Optional[pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs']] = None,
                 boolean_val: Optional[pulumi.Input['WorkspaceSettingV2BooleanValArgs']] = None,
                 effective_aibi_dashboard_embedding_access_policy: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs']] = None,
                 effective_aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs']] = None,
                 effective_automatic_cluster_update_workspace: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs']] = None,
                 effective_personal_compute: Optional[pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs']] = None,
                 effective_restrict_workspace_admins: Optional[pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs']] = None,
                 integer_val: Optional[pulumi.Input['WorkspaceSettingV2IntegerValArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 personal_compute: Optional[pulumi.Input['WorkspaceSettingV2PersonalComputeArgs']] = None,
                 provider_config: Optional[pulumi.Input['WorkspaceSettingV2ProviderConfigArgs']] = None,
                 restrict_workspace_admins: Optional[pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs']] = None,
                 string_val: Optional[pulumi.Input['WorkspaceSettingV2StringValArgs']] = None):
        """
        The set of arguments for constructing a WorkspaceSettingV2 resource.
        :param pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs'] aibi_dashboard_embedding_access_policy: Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        :param pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs'] aibi_dashboard_embedding_approved_domains: Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        :param pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs'] automatic_cluster_update_workspace: Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        :param pulumi.Input['WorkspaceSettingV2BooleanValArgs'] boolean_val: Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        :param pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs'] effective_aibi_dashboard_embedding_access_policy: Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        :param pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs'] effective_aibi_dashboard_embedding_approved_domains: Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        :param pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs'] effective_automatic_cluster_update_workspace: Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        :param pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs'] effective_personal_compute: Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        :param pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs'] effective_restrict_workspace_admins: Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        :param pulumi.Input['WorkspaceSettingV2IntegerValArgs'] integer_val: Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        :param pulumi.Input[_builtins.str] name: Name of the setting
        :param pulumi.Input['WorkspaceSettingV2PersonalComputeArgs'] personal_compute: Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        :param pulumi.Input['WorkspaceSettingV2ProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs'] restrict_workspace_admins: Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        :param pulumi.Input['WorkspaceSettingV2StringValArgs'] string_val: Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        if aibi_dashboard_embedding_access_policy is not None:
            pulumi.set(__self__, "aibi_dashboard_embedding_access_policy", aibi_dashboard_embedding_access_policy)
        if aibi_dashboard_embedding_approved_domains is not None:
            pulumi.set(__self__, "aibi_dashboard_embedding_approved_domains", aibi_dashboard_embedding_approved_domains)
        if automatic_cluster_update_workspace is not None:
            pulumi.set(__self__, "automatic_cluster_update_workspace", automatic_cluster_update_workspace)
        if boolean_val is not None:
            pulumi.set(__self__, "boolean_val", boolean_val)
        if effective_aibi_dashboard_embedding_access_policy is not None:
            pulumi.set(__self__, "effective_aibi_dashboard_embedding_access_policy", effective_aibi_dashboard_embedding_access_policy)
        if effective_aibi_dashboard_embedding_approved_domains is not None:
            pulumi.set(__self__, "effective_aibi_dashboard_embedding_approved_domains", effective_aibi_dashboard_embedding_approved_domains)
        if effective_automatic_cluster_update_workspace is not None:
            pulumi.set(__self__, "effective_automatic_cluster_update_workspace", effective_automatic_cluster_update_workspace)
        if effective_personal_compute is not None:
            pulumi.set(__self__, "effective_personal_compute", effective_personal_compute)
        if effective_restrict_workspace_admins is not None:
            pulumi.set(__self__, "effective_restrict_workspace_admins", effective_restrict_workspace_admins)
        if integer_val is not None:
            pulumi.set(__self__, "integer_val", integer_val)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if personal_compute is not None:
            pulumi.set(__self__, "personal_compute", personal_compute)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if restrict_workspace_admins is not None:
            pulumi.set(__self__, "restrict_workspace_admins", restrict_workspace_admins)
        if string_val is not None:
            pulumi.set(__self__, "string_val", string_val)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingAccessPolicy")
    def aibi_dashboard_embedding_access_policy(self) -> Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs']]:
        """
        Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        """
        return pulumi.get(self, "aibi_dashboard_embedding_access_policy")

    @aibi_dashboard_embedding_access_policy.setter
    def aibi_dashboard_embedding_access_policy(self, value: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs']]):
        pulumi.set(self, "aibi_dashboard_embedding_access_policy", value)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs']]:
        """
        Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @aibi_dashboard_embedding_approved_domains.setter
    def aibi_dashboard_embedding_approved_domains(self, value: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs']]):
        pulumi.set(self, "aibi_dashboard_embedding_approved_domains", value)

    @_builtins.property
    @pulumi.getter(name="automaticClusterUpdateWorkspace")
    def automatic_cluster_update_workspace(self) -> Optional[pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs']]:
        """
        Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        """
        return pulumi.get(self, "automatic_cluster_update_workspace")

    @automatic_cluster_update_workspace.setter
    def automatic_cluster_update_workspace(self, value: Optional[pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs']]):
        pulumi.set(self, "automatic_cluster_update_workspace", value)

    @_builtins.property
    @pulumi.getter(name="booleanVal")
    def boolean_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2BooleanValArgs']]:
        """
        Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        """
        return pulumi.get(self, "boolean_val")

    @boolean_val.setter
    def boolean_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2BooleanValArgs']]):
        pulumi.set(self, "boolean_val", value)

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingAccessPolicy")
    def effective_aibi_dashboard_embedding_access_policy(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs']]:
        """
        Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_access_policy")

    @effective_aibi_dashboard_embedding_access_policy.setter
    def effective_aibi_dashboard_embedding_access_policy(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs']]):
        pulumi.set(self, "effective_aibi_dashboard_embedding_access_policy", value)

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingApprovedDomains")
    def effective_aibi_dashboard_embedding_approved_domains(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs']]:
        """
        Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_approved_domains")

    @effective_aibi_dashboard_embedding_approved_domains.setter
    def effective_aibi_dashboard_embedding_approved_domains(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs']]):
        pulumi.set(self, "effective_aibi_dashboard_embedding_approved_domains", value)

    @_builtins.property
    @pulumi.getter(name="effectiveAutomaticClusterUpdateWorkspace")
    def effective_automatic_cluster_update_workspace(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs']]:
        """
        Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        """
        return pulumi.get(self, "effective_automatic_cluster_update_workspace")

    @effective_automatic_cluster_update_workspace.setter
    def effective_automatic_cluster_update_workspace(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs']]):
        pulumi.set(self, "effective_automatic_cluster_update_workspace", value)

    @_builtins.property
    @pulumi.getter(name="effectivePersonalCompute")
    def effective_personal_compute(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs']]:
        """
        Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        """
        return pulumi.get(self, "effective_personal_compute")

    @effective_personal_compute.setter
    def effective_personal_compute(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs']]):
        pulumi.set(self, "effective_personal_compute", value)

    @_builtins.property
    @pulumi.getter(name="effectiveRestrictWorkspaceAdmins")
    def effective_restrict_workspace_admins(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs']]:
        """
        Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        """
        return pulumi.get(self, "effective_restrict_workspace_admins")

    @effective_restrict_workspace_admins.setter
    def effective_restrict_workspace_admins(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs']]):
        pulumi.set(self, "effective_restrict_workspace_admins", value)

    @_builtins.property
    @pulumi.getter(name="integerVal")
    def integer_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2IntegerValArgs']]:
        """
        Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        """
        return pulumi.get(self, "integer_val")

    @integer_val.setter
    def integer_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2IntegerValArgs']]):
        pulumi.set(self, "integer_val", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the setting
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="personalCompute")
    def personal_compute(self) -> Optional[pulumi.Input['WorkspaceSettingV2PersonalComputeArgs']]:
        """
        Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        """
        return pulumi.get(self, "personal_compute")

    @personal_compute.setter
    def personal_compute(self, value: Optional[pulumi.Input['WorkspaceSettingV2PersonalComputeArgs']]):
        pulumi.set(self, "personal_compute", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['WorkspaceSettingV2ProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['WorkspaceSettingV2ProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="restrictWorkspaceAdmins")
    def restrict_workspace_admins(self) -> Optional[pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs']]:
        """
        Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        """
        return pulumi.get(self, "restrict_workspace_admins")

    @restrict_workspace_admins.setter
    def restrict_workspace_admins(self, value: Optional[pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs']]):
        pulumi.set(self, "restrict_workspace_admins", value)

    @_builtins.property
    @pulumi.getter(name="stringVal")
    def string_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2StringValArgs']]:
        """
        Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        return pulumi.get(self, "string_val")

    @string_val.setter
    def string_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2StringValArgs']]):
        pulumi.set(self, "string_val", value)


@pulumi.input_type
class _WorkspaceSettingV2State:
    def __init__(__self__, *,
                 aibi_dashboard_embedding_access_policy: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs']] = None,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs']] = None,
                 automatic_cluster_update_workspace: Optional[pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs']] = None,
                 boolean_val: Optional[pulumi.Input['WorkspaceSettingV2BooleanValArgs']] = None,
                 effective_aibi_dashboard_embedding_access_policy: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs']] = None,
                 effective_aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs']] = None,
                 effective_automatic_cluster_update_workspace: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs']] = None,
                 effective_boolean_val: Optional[pulumi.Input['WorkspaceSettingV2EffectiveBooleanValArgs']] = None,
                 effective_integer_val: Optional[pulumi.Input['WorkspaceSettingV2EffectiveIntegerValArgs']] = None,
                 effective_personal_compute: Optional[pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs']] = None,
                 effective_restrict_workspace_admins: Optional[pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs']] = None,
                 effective_string_val: Optional[pulumi.Input['WorkspaceSettingV2EffectiveStringValArgs']] = None,
                 integer_val: Optional[pulumi.Input['WorkspaceSettingV2IntegerValArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 personal_compute: Optional[pulumi.Input['WorkspaceSettingV2PersonalComputeArgs']] = None,
                 provider_config: Optional[pulumi.Input['WorkspaceSettingV2ProviderConfigArgs']] = None,
                 restrict_workspace_admins: Optional[pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs']] = None,
                 string_val: Optional[pulumi.Input['WorkspaceSettingV2StringValArgs']] = None):
        """
        Input properties used for looking up and filtering WorkspaceSettingV2 resources.
        :param pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs'] aibi_dashboard_embedding_access_policy: Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        :param pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs'] aibi_dashboard_embedding_approved_domains: Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        :param pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs'] automatic_cluster_update_workspace: Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        :param pulumi.Input['WorkspaceSettingV2BooleanValArgs'] boolean_val: Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        :param pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs'] effective_aibi_dashboard_embedding_access_policy: Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        :param pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs'] effective_aibi_dashboard_embedding_approved_domains: Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        :param pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs'] effective_automatic_cluster_update_workspace: Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        :param pulumi.Input['WorkspaceSettingV2EffectiveBooleanValArgs'] effective_boolean_val: (BooleanMessage) - Effective setting value for boolean type setting. This is the final effective value of setting. To set a value use boolean_val
        :param pulumi.Input['WorkspaceSettingV2EffectiveIntegerValArgs'] effective_integer_val: (IntegerMessage) - Effective setting value for integer type setting. This is the final effective value of setting. To set a value use integer_val
        :param pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs'] effective_personal_compute: Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        :param pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs'] effective_restrict_workspace_admins: Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        :param pulumi.Input['WorkspaceSettingV2EffectiveStringValArgs'] effective_string_val: (StringMessage) - Effective setting value for string type setting. This is the final effective value of setting. To set a value use string_val
        :param pulumi.Input['WorkspaceSettingV2IntegerValArgs'] integer_val: Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        :param pulumi.Input[_builtins.str] name: Name of the setting
        :param pulumi.Input['WorkspaceSettingV2PersonalComputeArgs'] personal_compute: Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        :param pulumi.Input['WorkspaceSettingV2ProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs'] restrict_workspace_admins: Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        :param pulumi.Input['WorkspaceSettingV2StringValArgs'] string_val: Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        if aibi_dashboard_embedding_access_policy is not None:
            pulumi.set(__self__, "aibi_dashboard_embedding_access_policy", aibi_dashboard_embedding_access_policy)
        if aibi_dashboard_embedding_approved_domains is not None:
            pulumi.set(__self__, "aibi_dashboard_embedding_approved_domains", aibi_dashboard_embedding_approved_domains)
        if automatic_cluster_update_workspace is not None:
            pulumi.set(__self__, "automatic_cluster_update_workspace", automatic_cluster_update_workspace)
        if boolean_val is not None:
            pulumi.set(__self__, "boolean_val", boolean_val)
        if effective_aibi_dashboard_embedding_access_policy is not None:
            pulumi.set(__self__, "effective_aibi_dashboard_embedding_access_policy", effective_aibi_dashboard_embedding_access_policy)
        if effective_aibi_dashboard_embedding_approved_domains is not None:
            pulumi.set(__self__, "effective_aibi_dashboard_embedding_approved_domains", effective_aibi_dashboard_embedding_approved_domains)
        if effective_automatic_cluster_update_workspace is not None:
            pulumi.set(__self__, "effective_automatic_cluster_update_workspace", effective_automatic_cluster_update_workspace)
        if effective_boolean_val is not None:
            pulumi.set(__self__, "effective_boolean_val", effective_boolean_val)
        if effective_integer_val is not None:
            pulumi.set(__self__, "effective_integer_val", effective_integer_val)
        if effective_personal_compute is not None:
            pulumi.set(__self__, "effective_personal_compute", effective_personal_compute)
        if effective_restrict_workspace_admins is not None:
            pulumi.set(__self__, "effective_restrict_workspace_admins", effective_restrict_workspace_admins)
        if effective_string_val is not None:
            pulumi.set(__self__, "effective_string_val", effective_string_val)
        if integer_val is not None:
            pulumi.set(__self__, "integer_val", integer_val)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if personal_compute is not None:
            pulumi.set(__self__, "personal_compute", personal_compute)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if restrict_workspace_admins is not None:
            pulumi.set(__self__, "restrict_workspace_admins", restrict_workspace_admins)
        if string_val is not None:
            pulumi.set(__self__, "string_val", string_val)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingAccessPolicy")
    def aibi_dashboard_embedding_access_policy(self) -> Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs']]:
        """
        Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        """
        return pulumi.get(self, "aibi_dashboard_embedding_access_policy")

    @aibi_dashboard_embedding_access_policy.setter
    def aibi_dashboard_embedding_access_policy(self, value: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs']]):
        pulumi.set(self, "aibi_dashboard_embedding_access_policy", value)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs']]:
        """
        Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @aibi_dashboard_embedding_approved_domains.setter
    def aibi_dashboard_embedding_approved_domains(self, value: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs']]):
        pulumi.set(self, "aibi_dashboard_embedding_approved_domains", value)

    @_builtins.property
    @pulumi.getter(name="automaticClusterUpdateWorkspace")
    def automatic_cluster_update_workspace(self) -> Optional[pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs']]:
        """
        Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        """
        return pulumi.get(self, "automatic_cluster_update_workspace")

    @automatic_cluster_update_workspace.setter
    def automatic_cluster_update_workspace(self, value: Optional[pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs']]):
        pulumi.set(self, "automatic_cluster_update_workspace", value)

    @_builtins.property
    @pulumi.getter(name="booleanVal")
    def boolean_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2BooleanValArgs']]:
        """
        Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        """
        return pulumi.get(self, "boolean_val")

    @boolean_val.setter
    def boolean_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2BooleanValArgs']]):
        pulumi.set(self, "boolean_val", value)

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingAccessPolicy")
    def effective_aibi_dashboard_embedding_access_policy(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs']]:
        """
        Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_access_policy")

    @effective_aibi_dashboard_embedding_access_policy.setter
    def effective_aibi_dashboard_embedding_access_policy(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs']]):
        pulumi.set(self, "effective_aibi_dashboard_embedding_access_policy", value)

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingApprovedDomains")
    def effective_aibi_dashboard_embedding_approved_domains(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs']]:
        """
        Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_approved_domains")

    @effective_aibi_dashboard_embedding_approved_domains.setter
    def effective_aibi_dashboard_embedding_approved_domains(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs']]):
        pulumi.set(self, "effective_aibi_dashboard_embedding_approved_domains", value)

    @_builtins.property
    @pulumi.getter(name="effectiveAutomaticClusterUpdateWorkspace")
    def effective_automatic_cluster_update_workspace(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs']]:
        """
        Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        """
        return pulumi.get(self, "effective_automatic_cluster_update_workspace")

    @effective_automatic_cluster_update_workspace.setter
    def effective_automatic_cluster_update_workspace(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs']]):
        pulumi.set(self, "effective_automatic_cluster_update_workspace", value)

    @_builtins.property
    @pulumi.getter(name="effectiveBooleanVal")
    def effective_boolean_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveBooleanValArgs']]:
        """
        (BooleanMessage) - Effective setting value for boolean type setting. This is the final effective value of setting. To set a value use boolean_val
        """
        return pulumi.get(self, "effective_boolean_val")

    @effective_boolean_val.setter
    def effective_boolean_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveBooleanValArgs']]):
        pulumi.set(self, "effective_boolean_val", value)

    @_builtins.property
    @pulumi.getter(name="effectiveIntegerVal")
    def effective_integer_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveIntegerValArgs']]:
        """
        (IntegerMessage) - Effective setting value for integer type setting. This is the final effective value of setting. To set a value use integer_val
        """
        return pulumi.get(self, "effective_integer_val")

    @effective_integer_val.setter
    def effective_integer_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveIntegerValArgs']]):
        pulumi.set(self, "effective_integer_val", value)

    @_builtins.property
    @pulumi.getter(name="effectivePersonalCompute")
    def effective_personal_compute(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs']]:
        """
        Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        """
        return pulumi.get(self, "effective_personal_compute")

    @effective_personal_compute.setter
    def effective_personal_compute(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs']]):
        pulumi.set(self, "effective_personal_compute", value)

    @_builtins.property
    @pulumi.getter(name="effectiveRestrictWorkspaceAdmins")
    def effective_restrict_workspace_admins(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs']]:
        """
        Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        """
        return pulumi.get(self, "effective_restrict_workspace_admins")

    @effective_restrict_workspace_admins.setter
    def effective_restrict_workspace_admins(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs']]):
        pulumi.set(self, "effective_restrict_workspace_admins", value)

    @_builtins.property
    @pulumi.getter(name="effectiveStringVal")
    def effective_string_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveStringValArgs']]:
        """
        (StringMessage) - Effective setting value for string type setting. This is the final effective value of setting. To set a value use string_val
        """
        return pulumi.get(self, "effective_string_val")

    @effective_string_val.setter
    def effective_string_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveStringValArgs']]):
        pulumi.set(self, "effective_string_val", value)

    @_builtins.property
    @pulumi.getter(name="integerVal")
    def integer_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2IntegerValArgs']]:
        """
        Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        """
        return pulumi.get(self, "integer_val")

    @integer_val.setter
    def integer_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2IntegerValArgs']]):
        pulumi.set(self, "integer_val", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the setting
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="personalCompute")
    def personal_compute(self) -> Optional[pulumi.Input['WorkspaceSettingV2PersonalComputeArgs']]:
        """
        Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        """
        return pulumi.get(self, "personal_compute")

    @personal_compute.setter
    def personal_compute(self, value: Optional[pulumi.Input['WorkspaceSettingV2PersonalComputeArgs']]):
        pulumi.set(self, "personal_compute", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['WorkspaceSettingV2ProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['WorkspaceSettingV2ProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="restrictWorkspaceAdmins")
    def restrict_workspace_admins(self) -> Optional[pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs']]:
        """
        Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        """
        return pulumi.get(self, "restrict_workspace_admins")

    @restrict_workspace_admins.setter
    def restrict_workspace_admins(self, value: Optional[pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs']]):
        pulumi.set(self, "restrict_workspace_admins", value)

    @_builtins.property
    @pulumi.getter(name="stringVal")
    def string_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2StringValArgs']]:
        """
        Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        return pulumi.get(self, "string_val")

    @string_val.setter
    def string_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2StringValArgs']]):
        pulumi.set(self, "string_val", value)


@pulumi.type_token("databricks:index/workspaceSettingV2:WorkspaceSettingV2")
class WorkspaceSettingV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aibi_dashboard_embedding_access_policy: Optional[pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgsDict']]] = None,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
                 automatic_cluster_update_workspace: Optional[pulumi.Input[Union['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgsDict']]] = None,
                 boolean_val: Optional[pulumi.Input[Union['WorkspaceSettingV2BooleanValArgs', 'WorkspaceSettingV2BooleanValArgsDict']]] = None,
                 effective_aibi_dashboard_embedding_access_policy: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgsDict']]] = None,
                 effective_aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
                 effective_automatic_cluster_update_workspace: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgsDict']]] = None,
                 effective_personal_compute: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectivePersonalComputeArgs', 'WorkspaceSettingV2EffectivePersonalComputeArgsDict']]] = None,
                 effective_restrict_workspace_admins: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgsDict']]] = None,
                 integer_val: Optional[pulumi.Input[Union['WorkspaceSettingV2IntegerValArgs', 'WorkspaceSettingV2IntegerValArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 personal_compute: Optional[pulumi.Input[Union['WorkspaceSettingV2PersonalComputeArgs', 'WorkspaceSettingV2PersonalComputeArgsDict']]] = None,
                 provider_config: Optional[pulumi.Input[Union['WorkspaceSettingV2ProviderConfigArgs', 'WorkspaceSettingV2ProviderConfigArgsDict']]] = None,
                 restrict_workspace_admins: Optional[pulumi.Input[Union['WorkspaceSettingV2RestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2RestrictWorkspaceAdminsArgsDict']]] = None,
                 string_val: Optional[pulumi.Input[Union['WorkspaceSettingV2StringValArgs', 'WorkspaceSettingV2StringValArgsDict']]] = None,
                 __props__=None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Setting is a configurable value or control that determines how a feature or behavior works within the databricks platform.

        [//]: # (todo: add public link to metadata api after production doc link available)
        See settings-metadata api for list of settings that can be modified using this resource.

        ## Example Usage

        Getting a workspace level setting:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.WorkspaceSettingV2("this",
            name="llm_proxy_partner_powered",
            boolean_val={
                "value": False,
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgsDict']] aibi_dashboard_embedding_access_policy: Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgsDict']] aibi_dashboard_embedding_approved_domains: Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgsDict']] automatic_cluster_update_workspace: Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2BooleanValArgs', 'WorkspaceSettingV2BooleanValArgsDict']] boolean_val: Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgsDict']] effective_aibi_dashboard_embedding_access_policy: Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgsDict']] effective_aibi_dashboard_embedding_approved_domains: Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgsDict']] effective_automatic_cluster_update_workspace: Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        :param pulumi.Input[Union['WorkspaceSettingV2EffectivePersonalComputeArgs', 'WorkspaceSettingV2EffectivePersonalComputeArgsDict']] effective_personal_compute: Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgsDict']] effective_restrict_workspace_admins: Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        :param pulumi.Input[Union['WorkspaceSettingV2IntegerValArgs', 'WorkspaceSettingV2IntegerValArgsDict']] integer_val: Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        :param pulumi.Input[_builtins.str] name: Name of the setting
        :param pulumi.Input[Union['WorkspaceSettingV2PersonalComputeArgs', 'WorkspaceSettingV2PersonalComputeArgsDict']] personal_compute: Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2ProviderConfigArgs', 'WorkspaceSettingV2ProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Union['WorkspaceSettingV2RestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2RestrictWorkspaceAdminsArgsDict']] restrict_workspace_admins: Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2StringValArgs', 'WorkspaceSettingV2StringValArgsDict']] string_val: Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[WorkspaceSettingV2Args] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Setting is a configurable value or control that determines how a feature or behavior works within the databricks platform.

        [//]: # (todo: add public link to metadata api after production doc link available)
        See settings-metadata api for list of settings that can be modified using this resource.

        ## Example Usage

        Getting a workspace level setting:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.WorkspaceSettingV2("this",
            name="llm_proxy_partner_powered",
            boolean_val={
                "value": False,
            })
        ```

        :param str resource_name: The name of the resource.
        :param WorkspaceSettingV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkspaceSettingV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aibi_dashboard_embedding_access_policy: Optional[pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgsDict']]] = None,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
                 automatic_cluster_update_workspace: Optional[pulumi.Input[Union['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgsDict']]] = None,
                 boolean_val: Optional[pulumi.Input[Union['WorkspaceSettingV2BooleanValArgs', 'WorkspaceSettingV2BooleanValArgsDict']]] = None,
                 effective_aibi_dashboard_embedding_access_policy: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgsDict']]] = None,
                 effective_aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
                 effective_automatic_cluster_update_workspace: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgsDict']]] = None,
                 effective_personal_compute: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectivePersonalComputeArgs', 'WorkspaceSettingV2EffectivePersonalComputeArgsDict']]] = None,
                 effective_restrict_workspace_admins: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgsDict']]] = None,
                 integer_val: Optional[pulumi.Input[Union['WorkspaceSettingV2IntegerValArgs', 'WorkspaceSettingV2IntegerValArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 personal_compute: Optional[pulumi.Input[Union['WorkspaceSettingV2PersonalComputeArgs', 'WorkspaceSettingV2PersonalComputeArgsDict']]] = None,
                 provider_config: Optional[pulumi.Input[Union['WorkspaceSettingV2ProviderConfigArgs', 'WorkspaceSettingV2ProviderConfigArgsDict']]] = None,
                 restrict_workspace_admins: Optional[pulumi.Input[Union['WorkspaceSettingV2RestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2RestrictWorkspaceAdminsArgsDict']]] = None,
                 string_val: Optional[pulumi.Input[Union['WorkspaceSettingV2StringValArgs', 'WorkspaceSettingV2StringValArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkspaceSettingV2Args.__new__(WorkspaceSettingV2Args)

            __props__.__dict__["aibi_dashboard_embedding_access_policy"] = aibi_dashboard_embedding_access_policy
            __props__.__dict__["aibi_dashboard_embedding_approved_domains"] = aibi_dashboard_embedding_approved_domains
            __props__.__dict__["automatic_cluster_update_workspace"] = automatic_cluster_update_workspace
            __props__.__dict__["boolean_val"] = boolean_val
            __props__.__dict__["effective_aibi_dashboard_embedding_access_policy"] = effective_aibi_dashboard_embedding_access_policy
            __props__.__dict__["effective_aibi_dashboard_embedding_approved_domains"] = effective_aibi_dashboard_embedding_approved_domains
            __props__.__dict__["effective_automatic_cluster_update_workspace"] = effective_automatic_cluster_update_workspace
            __props__.__dict__["effective_personal_compute"] = effective_personal_compute
            __props__.__dict__["effective_restrict_workspace_admins"] = effective_restrict_workspace_admins
            __props__.__dict__["integer_val"] = integer_val
            __props__.__dict__["name"] = name
            __props__.__dict__["personal_compute"] = personal_compute
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["restrict_workspace_admins"] = restrict_workspace_admins
            __props__.__dict__["string_val"] = string_val
            __props__.__dict__["effective_boolean_val"] = None
            __props__.__dict__["effective_integer_val"] = None
            __props__.__dict__["effective_string_val"] = None
        super(WorkspaceSettingV2, __self__).__init__(
            'databricks:index/workspaceSettingV2:WorkspaceSettingV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aibi_dashboard_embedding_access_policy: Optional[pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgsDict']]] = None,
            aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
            automatic_cluster_update_workspace: Optional[pulumi.Input[Union['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgsDict']]] = None,
            boolean_val: Optional[pulumi.Input[Union['WorkspaceSettingV2BooleanValArgs', 'WorkspaceSettingV2BooleanValArgsDict']]] = None,
            effective_aibi_dashboard_embedding_access_policy: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgsDict']]] = None,
            effective_aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
            effective_automatic_cluster_update_workspace: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgsDict']]] = None,
            effective_boolean_val: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveBooleanValArgs', 'WorkspaceSettingV2EffectiveBooleanValArgsDict']]] = None,
            effective_integer_val: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveIntegerValArgs', 'WorkspaceSettingV2EffectiveIntegerValArgsDict']]] = None,
            effective_personal_compute: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectivePersonalComputeArgs', 'WorkspaceSettingV2EffectivePersonalComputeArgsDict']]] = None,
            effective_restrict_workspace_admins: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgsDict']]] = None,
            effective_string_val: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveStringValArgs', 'WorkspaceSettingV2EffectiveStringValArgsDict']]] = None,
            integer_val: Optional[pulumi.Input[Union['WorkspaceSettingV2IntegerValArgs', 'WorkspaceSettingV2IntegerValArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            personal_compute: Optional[pulumi.Input[Union['WorkspaceSettingV2PersonalComputeArgs', 'WorkspaceSettingV2PersonalComputeArgsDict']]] = None,
            provider_config: Optional[pulumi.Input[Union['WorkspaceSettingV2ProviderConfigArgs', 'WorkspaceSettingV2ProviderConfigArgsDict']]] = None,
            restrict_workspace_admins: Optional[pulumi.Input[Union['WorkspaceSettingV2RestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2RestrictWorkspaceAdminsArgsDict']]] = None,
            string_val: Optional[pulumi.Input[Union['WorkspaceSettingV2StringValArgs', 'WorkspaceSettingV2StringValArgsDict']]] = None) -> 'WorkspaceSettingV2':
        """
        Get an existing WorkspaceSettingV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgsDict']] aibi_dashboard_embedding_access_policy: Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgsDict']] aibi_dashboard_embedding_approved_domains: Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgsDict']] automatic_cluster_update_workspace: Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2BooleanValArgs', 'WorkspaceSettingV2BooleanValArgsDict']] boolean_val: Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgsDict']] effective_aibi_dashboard_embedding_access_policy: Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgsDict']] effective_aibi_dashboard_embedding_approved_domains: Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgsDict']] effective_automatic_cluster_update_workspace: Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveBooleanValArgs', 'WorkspaceSettingV2EffectiveBooleanValArgsDict']] effective_boolean_val: (BooleanMessage) - Effective setting value for boolean type setting. This is the final effective value of setting. To set a value use boolean_val
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveIntegerValArgs', 'WorkspaceSettingV2EffectiveIntegerValArgsDict']] effective_integer_val: (IntegerMessage) - Effective setting value for integer type setting. This is the final effective value of setting. To set a value use integer_val
        :param pulumi.Input[Union['WorkspaceSettingV2EffectivePersonalComputeArgs', 'WorkspaceSettingV2EffectivePersonalComputeArgsDict']] effective_personal_compute: Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgsDict']] effective_restrict_workspace_admins: Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveStringValArgs', 'WorkspaceSettingV2EffectiveStringValArgsDict']] effective_string_val: (StringMessage) - Effective setting value for string type setting. This is the final effective value of setting. To set a value use string_val
        :param pulumi.Input[Union['WorkspaceSettingV2IntegerValArgs', 'WorkspaceSettingV2IntegerValArgsDict']] integer_val: Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        :param pulumi.Input[_builtins.str] name: Name of the setting
        :param pulumi.Input[Union['WorkspaceSettingV2PersonalComputeArgs', 'WorkspaceSettingV2PersonalComputeArgsDict']] personal_compute: Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2ProviderConfigArgs', 'WorkspaceSettingV2ProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Union['WorkspaceSettingV2RestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2RestrictWorkspaceAdminsArgsDict']] restrict_workspace_admins: Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2StringValArgs', 'WorkspaceSettingV2StringValArgsDict']] string_val: Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkspaceSettingV2State.__new__(_WorkspaceSettingV2State)

        __props__.__dict__["aibi_dashboard_embedding_access_policy"] = aibi_dashboard_embedding_access_policy
        __props__.__dict__["aibi_dashboard_embedding_approved_domains"] = aibi_dashboard_embedding_approved_domains
        __props__.__dict__["automatic_cluster_update_workspace"] = automatic_cluster_update_workspace
        __props__.__dict__["boolean_val"] = boolean_val
        __props__.__dict__["effective_aibi_dashboard_embedding_access_policy"] = effective_aibi_dashboard_embedding_access_policy
        __props__.__dict__["effective_aibi_dashboard_embedding_approved_domains"] = effective_aibi_dashboard_embedding_approved_domains
        __props__.__dict__["effective_automatic_cluster_update_workspace"] = effective_automatic_cluster_update_workspace
        __props__.__dict__["effective_boolean_val"] = effective_boolean_val
        __props__.__dict__["effective_integer_val"] = effective_integer_val
        __props__.__dict__["effective_personal_compute"] = effective_personal_compute
        __props__.__dict__["effective_restrict_workspace_admins"] = effective_restrict_workspace_admins
        __props__.__dict__["effective_string_val"] = effective_string_val
        __props__.__dict__["integer_val"] = integer_val
        __props__.__dict__["name"] = name
        __props__.__dict__["personal_compute"] = personal_compute
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["restrict_workspace_admins"] = restrict_workspace_admins
        __props__.__dict__["string_val"] = string_val
        return WorkspaceSettingV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingAccessPolicy")
    def aibi_dashboard_embedding_access_policy(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicy']]:
        """
        Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        """
        return pulumi.get(self, "aibi_dashboard_embedding_access_policy")

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomains']]:
        """
        Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @_builtins.property
    @pulumi.getter(name="automaticClusterUpdateWorkspace")
    def automatic_cluster_update_workspace(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2AutomaticClusterUpdateWorkspace']]:
        """
        Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        """
        return pulumi.get(self, "automatic_cluster_update_workspace")

    @_builtins.property
    @pulumi.getter(name="booleanVal")
    def boolean_val(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2BooleanVal']]:
        """
        Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        """
        return pulumi.get(self, "boolean_val")

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingAccessPolicy")
    def effective_aibi_dashboard_embedding_access_policy(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicy']]:
        """
        Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_access_policy")

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingApprovedDomains")
    def effective_aibi_dashboard_embedding_approved_domains(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomains']]:
        """
        Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_approved_domains")

    @_builtins.property
    @pulumi.getter(name="effectiveAutomaticClusterUpdateWorkspace")
    def effective_automatic_cluster_update_workspace(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspace']]:
        """
        Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        """
        return pulumi.get(self, "effective_automatic_cluster_update_workspace")

    @_builtins.property
    @pulumi.getter(name="effectiveBooleanVal")
    def effective_boolean_val(self) -> pulumi.Output['outputs.WorkspaceSettingV2EffectiveBooleanVal']:
        """
        (BooleanMessage) - Effective setting value for boolean type setting. This is the final effective value of setting. To set a value use boolean_val
        """
        return pulumi.get(self, "effective_boolean_val")

    @_builtins.property
    @pulumi.getter(name="effectiveIntegerVal")
    def effective_integer_val(self) -> pulumi.Output['outputs.WorkspaceSettingV2EffectiveIntegerVal']:
        """
        (IntegerMessage) - Effective setting value for integer type setting. This is the final effective value of setting. To set a value use integer_val
        """
        return pulumi.get(self, "effective_integer_val")

    @_builtins.property
    @pulumi.getter(name="effectivePersonalCompute")
    def effective_personal_compute(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2EffectivePersonalCompute']]:
        """
        Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        """
        return pulumi.get(self, "effective_personal_compute")

    @_builtins.property
    @pulumi.getter(name="effectiveRestrictWorkspaceAdmins")
    def effective_restrict_workspace_admins(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2EffectiveRestrictWorkspaceAdmins']]:
        """
        Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        """
        return pulumi.get(self, "effective_restrict_workspace_admins")

    @_builtins.property
    @pulumi.getter(name="effectiveStringVal")
    def effective_string_val(self) -> pulumi.Output['outputs.WorkspaceSettingV2EffectiveStringVal']:
        """
        (StringMessage) - Effective setting value for string type setting. This is the final effective value of setting. To set a value use string_val
        """
        return pulumi.get(self, "effective_string_val")

    @_builtins.property
    @pulumi.getter(name="integerVal")
    def integer_val(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2IntegerVal']]:
        """
        Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        """
        return pulumi.get(self, "integer_val")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the setting
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="personalCompute")
    def personal_compute(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2PersonalCompute']]:
        """
        Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        """
        return pulumi.get(self, "personal_compute")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2ProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="restrictWorkspaceAdmins")
    def restrict_workspace_admins(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2RestrictWorkspaceAdmins']]:
        """
        Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        """
        return pulumi.get(self, "restrict_workspace_admins")

    @_builtins.property
    @pulumi.getter(name="stringVal")
    def string_val(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2StringVal']]:
        """
        Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        return pulumi.get(self, "string_val")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDataQualityRefreshResult',
    'AwaitableGetDataQualityRefreshResult',
    'get_data_quality_refresh',
    'get_data_quality_refresh_output',
]

@pulumi.output_type
class GetDataQualityRefreshResult:
    """
    A collection of values returned by getDataQualityRefresh.
    """
    def __init__(__self__, end_time_ms=None, id=None, message=None, object_id=None, object_type=None, provider_config=None, refresh_id=None, start_time_ms=None, state=None, trigger=None):
        if end_time_ms and not isinstance(end_time_ms, int):
            raise TypeError("Expected argument 'end_time_ms' to be a int")
        pulumi.set(__self__, "end_time_ms", end_time_ms)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if message and not isinstance(message, str):
            raise TypeError("Expected argument 'message' to be a str")
        pulumi.set(__self__, "message", message)
        if object_id and not isinstance(object_id, str):
            raise TypeError("Expected argument 'object_id' to be a str")
        pulumi.set(__self__, "object_id", object_id)
        if object_type and not isinstance(object_type, str):
            raise TypeError("Expected argument 'object_type' to be a str")
        pulumi.set(__self__, "object_type", object_type)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if refresh_id and not isinstance(refresh_id, int):
            raise TypeError("Expected argument 'refresh_id' to be a int")
        pulumi.set(__self__, "refresh_id", refresh_id)
        if start_time_ms and not isinstance(start_time_ms, int):
            raise TypeError("Expected argument 'start_time_ms' to be a int")
        pulumi.set(__self__, "start_time_ms", start_time_ms)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if trigger and not isinstance(trigger, str):
            raise TypeError("Expected argument 'trigger' to be a str")
        pulumi.set(__self__, "trigger", trigger)

    @_builtins.property
    @pulumi.getter(name="endTimeMs")
    def end_time_ms(self) -> _builtins.int:
        """
        (integer) - Time when the refresh ended (milliseconds since 1/1/1970 UTC)
        """
        return pulumi.get(self, "end_time_ms")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def message(self) -> _builtins.str:
        """
        (string) - An optional message to give insight into the current state of the refresh (e.g. FAILURE messages)
        """
        return pulumi.get(self, "message")

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> _builtins.str:
        """
        (string) - The UUID of the request object. It is `schema_id` for `schema`, and `table_id` for `table`.
        """
        return pulumi.get(self, "object_id")

    @_builtins.property
    @pulumi.getter(name="objectType")
    def object_type(self) -> _builtins.str:
        """
        (string) - The type of the monitored object. Can be one of the following: `schema`or `table`
        """
        return pulumi.get(self, "object_type")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetDataQualityRefreshProviderConfigResult']:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="refreshId")
    def refresh_id(self) -> _builtins.int:
        """
        (integer) - Unique id of the refresh operation
        """
        return pulumi.get(self, "refresh_id")

    @_builtins.property
    @pulumi.getter(name="startTimeMs")
    def start_time_ms(self) -> _builtins.int:
        """
        (integer) - Time when the refresh started (milliseconds since 1/1/1970 UTC)
        """
        return pulumi.get(self, "start_time_ms")

    @_builtins.property
    @pulumi.getter
    def state(self) -> _builtins.str:
        """
        (string) - The current state of the refresh. Possible values are: `MONITOR_REFRESH_STATE_CANCELED`, `MONITOR_REFRESH_STATE_FAILED`, `MONITOR_REFRESH_STATE_PENDING`, `MONITOR_REFRESH_STATE_RUNNING`, `MONITOR_REFRESH_STATE_SUCCESS`, `MONITOR_REFRESH_STATE_UNKNOWN`
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter
    def trigger(self) -> _builtins.str:
        """
        (string) - What triggered the refresh. Possible values are: `MONITOR_REFRESH_TRIGGER_DATA_CHANGE`, `MONITOR_REFRESH_TRIGGER_MANUAL`, `MONITOR_REFRESH_TRIGGER_SCHEDULE`, `MONITOR_REFRESH_TRIGGER_UNKNOWN`
        """
        return pulumi.get(self, "trigger")


class AwaitableGetDataQualityRefreshResult(GetDataQualityRefreshResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDataQualityRefreshResult(
            end_time_ms=self.end_time_ms,
            id=self.id,
            message=self.message,
            object_id=self.object_id,
            object_type=self.object_type,
            provider_config=self.provider_config,
            refresh_id=self.refresh_id,
            start_time_ms=self.start_time_ms,
            state=self.state,
            trigger=self.trigger)


def get_data_quality_refresh(object_id: Optional[_builtins.str] = None,
                             object_type: Optional[_builtins.str] = None,
                             provider_config: Optional[Union['GetDataQualityRefreshProviderConfigArgs', 'GetDataQualityRefreshProviderConfigArgsDict']] = None,
                             refresh_id: Optional[_builtins.int] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDataQualityRefreshResult:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to fetch a data quality refresh on a Unity Catalog table.

    The caller must either:
    1. be an owner of the table's parent catalog
    2. have **USE_CATALOG** on the table's parent catalog and be an owner of the table's parent schema.
    3. have the following permissions:
       - **USE_CATALOG** on the table's parent catalog
       - **USE_SCHEMA** on the table's parent schema
       - **SELECT** privilege on the table.

    > **Note** This data source can only be used with a workspace-level provider!

    ## Example Usage

    Getting a data quality refresh by Unity Catalog object type (currently supports `table`) and object id:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_table(name="my_catalog.my_schema.my_table")
    this_get_data_quality_refresh = databricks.get_data_quality_refresh(object_type="table",
        object_id=this.id)
    ```


    :param _builtins.str object_id: The UUID of the request object. It is `schema_id` for `schema`, and `table_id` for `table`.
           
           Find the `schema_id` from either:
           1. The [schema_id](https://docs.databricks.com/api/workspace/schemas/get#schema_id) of the `Schemas` resource.
           2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `schema` > go to the `Details` tab > the `Schema ID` field.
           
           Find the `table_id` from either:
           1. The [table_id](https://docs.databricks.com/api/workspace/tables/get#table_id) of the `Tables` resource.
           2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `table` > go to the `Details` tab > the `Table ID` field
    :param _builtins.str object_type: The type of the monitored object. Can be one of the following: `schema`or `table`
    :param Union['GetDataQualityRefreshProviderConfigArgs', 'GetDataQualityRefreshProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    :param _builtins.int refresh_id: Unique id of the refresh operation
    """
    __args__ = dict()
    __args__['objectId'] = object_id
    __args__['objectType'] = object_type
    __args__['providerConfig'] = provider_config
    __args__['refreshId'] = refresh_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getDataQualityRefresh:getDataQualityRefresh', __args__, opts=opts, typ=GetDataQualityRefreshResult).value

    return AwaitableGetDataQualityRefreshResult(
        end_time_ms=pulumi.get(__ret__, 'end_time_ms'),
        id=pulumi.get(__ret__, 'id'),
        message=pulumi.get(__ret__, 'message'),
        object_id=pulumi.get(__ret__, 'object_id'),
        object_type=pulumi.get(__ret__, 'object_type'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        refresh_id=pulumi.get(__ret__, 'refresh_id'),
        start_time_ms=pulumi.get(__ret__, 'start_time_ms'),
        state=pulumi.get(__ret__, 'state'),
        trigger=pulumi.get(__ret__, 'trigger'))
def get_data_quality_refresh_output(object_id: Optional[pulumi.Input[_builtins.str]] = None,
                                    object_type: Optional[pulumi.Input[_builtins.str]] = None,
                                    provider_config: Optional[pulumi.Input[Optional[Union['GetDataQualityRefreshProviderConfigArgs', 'GetDataQualityRefreshProviderConfigArgsDict']]]] = None,
                                    refresh_id: Optional[pulumi.Input[_builtins.int]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDataQualityRefreshResult]:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to fetch a data quality refresh on a Unity Catalog table.

    The caller must either:
    1. be an owner of the table's parent catalog
    2. have **USE_CATALOG** on the table's parent catalog and be an owner of the table's parent schema.
    3. have the following permissions:
       - **USE_CATALOG** on the table's parent catalog
       - **USE_SCHEMA** on the table's parent schema
       - **SELECT** privilege on the table.

    > **Note** This data source can only be used with a workspace-level provider!

    ## Example Usage

    Getting a data quality refresh by Unity Catalog object type (currently supports `table`) and object id:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_table(name="my_catalog.my_schema.my_table")
    this_get_data_quality_refresh = databricks.get_data_quality_refresh(object_type="table",
        object_id=this.id)
    ```


    :param _builtins.str object_id: The UUID of the request object. It is `schema_id` for `schema`, and `table_id` for `table`.
           
           Find the `schema_id` from either:
           1. The [schema_id](https://docs.databricks.com/api/workspace/schemas/get#schema_id) of the `Schemas` resource.
           2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `schema` > go to the `Details` tab > the `Schema ID` field.
           
           Find the `table_id` from either:
           1. The [table_id](https://docs.databricks.com/api/workspace/tables/get#table_id) of the `Tables` resource.
           2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `table` > go to the `Details` tab > the `Table ID` field
    :param _builtins.str object_type: The type of the monitored object. Can be one of the following: `schema`or `table`
    :param Union['GetDataQualityRefreshProviderConfigArgs', 'GetDataQualityRefreshProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    :param _builtins.int refresh_id: Unique id of the refresh operation
    """
    __args__ = dict()
    __args__['objectId'] = object_id
    __args__['objectType'] = object_type
    __args__['providerConfig'] = provider_config
    __args__['refreshId'] = refresh_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getDataQualityRefresh:getDataQualityRefresh', __args__, opts=opts, typ=GetDataQualityRefreshResult)
    return __ret__.apply(lambda __response__: GetDataQualityRefreshResult(
        end_time_ms=pulumi.get(__response__, 'end_time_ms'),
        id=pulumi.get(__response__, 'id'),
        message=pulumi.get(__response__, 'message'),
        object_id=pulumi.get(__response__, 'object_id'),
        object_type=pulumi.get(__response__, 'object_type'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        refresh_id=pulumi.get(__response__, 'refresh_id'),
        start_time_ms=pulumi.get(__response__, 'start_time_ms'),
        state=pulumi.get(__response__, 'state'),
        trigger=pulumi.get(__response__, 'trigger')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetPolicyInfosResult',
    'AwaitableGetPolicyInfosResult',
    'get_policy_infos',
    'get_policy_infos_output',
]

@pulumi.output_type
class GetPolicyInfosResult:
    """
    A collection of values returned by getPolicyInfos.
    """
    def __init__(__self__, id=None, include_inherited=None, max_results=None, on_securable_fullname=None, on_securable_type=None, policies=None, provider_config=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if include_inherited and not isinstance(include_inherited, bool):
            raise TypeError("Expected argument 'include_inherited' to be a bool")
        pulumi.set(__self__, "include_inherited", include_inherited)
        if max_results and not isinstance(max_results, int):
            raise TypeError("Expected argument 'max_results' to be a int")
        pulumi.set(__self__, "max_results", max_results)
        if on_securable_fullname and not isinstance(on_securable_fullname, str):
            raise TypeError("Expected argument 'on_securable_fullname' to be a str")
        pulumi.set(__self__, "on_securable_fullname", on_securable_fullname)
        if on_securable_type and not isinstance(on_securable_type, str):
            raise TypeError("Expected argument 'on_securable_type' to be a str")
        pulumi.set(__self__, "on_securable_type", on_securable_type)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="includeInherited")
    def include_inherited(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "include_inherited")

    @_builtins.property
    @pulumi.getter(name="maxResults")
    def max_results(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "max_results")

    @_builtins.property
    @pulumi.getter(name="onSecurableFullname")
    def on_securable_fullname(self) -> _builtins.str:
        """
        (string) - Full name of the securable on which the policy is defined.
        Required on create
        """
        return pulumi.get(self, "on_securable_fullname")

    @_builtins.property
    @pulumi.getter(name="onSecurableType")
    def on_securable_type(self) -> _builtins.str:
        """
        (string) - Type of the securable on which the policy is defined.
        Only `CATALOG`, `SCHEMA` and `TABLE` are supported at this moment.
        Required on create. Possible values are: `CATALOG`, `CLEAN_ROOM`, `CONNECTION`, `CREDENTIAL`, `EXTERNAL_LOCATION`, `EXTERNAL_METADATA`, `FUNCTION`, `METASTORE`, `PIPELINE`, `PROVIDER`, `RECIPIENT`, `SCHEMA`, `SHARE`, `STAGING_TABLE`, `STORAGE_CREDENTIAL`, `TABLE`, `VOLUME`
        """
        return pulumi.get(self, "on_securable_type")

    @_builtins.property
    @pulumi.getter
    def policies(self) -> Sequence['outputs.GetPolicyInfosPolicyResult']:
        return pulumi.get(self, "policies")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetPolicyInfosProviderConfigResult']:
        return pulumi.get(self, "provider_config")


class AwaitableGetPolicyInfosResult(GetPolicyInfosResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPolicyInfosResult(
            id=self.id,
            include_inherited=self.include_inherited,
            max_results=self.max_results,
            on_securable_fullname=self.on_securable_fullname,
            on_securable_type=self.on_securable_type,
            policies=self.policies,
            provider_config=self.provider_config)


def get_policy_infos(include_inherited: Optional[_builtins.bool] = None,
                     max_results: Optional[_builtins.int] = None,
                     on_securable_fullname: Optional[_builtins.str] = None,
                     on_securable_type: Optional[_builtins.str] = None,
                     provider_config: Optional[Union['GetPolicyInfosProviderConfigArgs', 'GetPolicyInfosProviderConfigArgsDict']] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPolicyInfosResult:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    Retrieves a list of all ABAC (Attribute-Based Access Control) policies defined on a specific securable in Unity Catalog. Use this data source to query all policies for a given securable type and name.

    ABAC policies provide governance for enforcing compliance through data attributes, allowing flexible and comprehensive access control based on conditions rather than specific resources.

    ## Example Usage

    ### List All Policies on a Securable

    ```python
    import pulumi
    import pulumi_databricks as databricks

    catalog_policies = databricks.get_policy_infos(on_securable_type="CATALOG",
        on_securable_fullname="main")
    ```


    :param _builtins.bool include_inherited: Optional. Whether to include policies defined on parent securables.
           By default, the inherited policies are not included
    :param _builtins.int max_results: Optional.  Maximum number of policies to return on a single page (page length).
           - When not set or set to 0, the page length is set to a server configured value (recommended);
           - When set to a value greater than 0, the page length is the minimum of this value and a server configured value;
    :param _builtins.str on_securable_fullname: Required. The fully qualified name of securable to list policies for
    :param _builtins.str on_securable_type: Required. The type of the securable to list policies for
    :param Union['GetPolicyInfosProviderConfigArgs', 'GetPolicyInfosProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['includeInherited'] = include_inherited
    __args__['maxResults'] = max_results
    __args__['onSecurableFullname'] = on_securable_fullname
    __args__['onSecurableType'] = on_securable_type
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getPolicyInfos:getPolicyInfos', __args__, opts=opts, typ=GetPolicyInfosResult).value

    return AwaitableGetPolicyInfosResult(
        id=pulumi.get(__ret__, 'id'),
        include_inherited=pulumi.get(__ret__, 'include_inherited'),
        max_results=pulumi.get(__ret__, 'max_results'),
        on_securable_fullname=pulumi.get(__ret__, 'on_securable_fullname'),
        on_securable_type=pulumi.get(__ret__, 'on_securable_type'),
        policies=pulumi.get(__ret__, 'policies'),
        provider_config=pulumi.get(__ret__, 'provider_config'))
def get_policy_infos_output(include_inherited: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                            max_results: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                            on_securable_fullname: Optional[pulumi.Input[_builtins.str]] = None,
                            on_securable_type: Optional[pulumi.Input[_builtins.str]] = None,
                            provider_config: Optional[pulumi.Input[Optional[Union['GetPolicyInfosProviderConfigArgs', 'GetPolicyInfosProviderConfigArgsDict']]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPolicyInfosResult]:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    Retrieves a list of all ABAC (Attribute-Based Access Control) policies defined on a specific securable in Unity Catalog. Use this data source to query all policies for a given securable type and name.

    ABAC policies provide governance for enforcing compliance through data attributes, allowing flexible and comprehensive access control based on conditions rather than specific resources.

    ## Example Usage

    ### List All Policies on a Securable

    ```python
    import pulumi
    import pulumi_databricks as databricks

    catalog_policies = databricks.get_policy_infos(on_securable_type="CATALOG",
        on_securable_fullname="main")
    ```


    :param _builtins.bool include_inherited: Optional. Whether to include policies defined on parent securables.
           By default, the inherited policies are not included
    :param _builtins.int max_results: Optional.  Maximum number of policies to return on a single page (page length).
           - When not set or set to 0, the page length is set to a server configured value (recommended);
           - When set to a value greater than 0, the page length is the minimum of this value and a server configured value;
    :param _builtins.str on_securable_fullname: Required. The fully qualified name of securable to list policies for
    :param _builtins.str on_securable_type: Required. The type of the securable to list policies for
    :param Union['GetPolicyInfosProviderConfigArgs', 'GetPolicyInfosProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['includeInherited'] = include_inherited
    __args__['maxResults'] = max_results
    __args__['onSecurableFullname'] = on_securable_fullname
    __args__['onSecurableType'] = on_securable_type
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getPolicyInfos:getPolicyInfos', __args__, opts=opts, typ=GetPolicyInfosResult)
    return __ret__.apply(lambda __response__: GetPolicyInfosResult(
        id=pulumi.get(__response__, 'id'),
        include_inherited=pulumi.get(__response__, 'include_inherited'),
        max_results=pulumi.get(__response__, 'max_results'),
        on_securable_fullname=pulumi.get(__response__, 'on_securable_fullname'),
        on_securable_type=pulumi.get(__response__, 'on_securable_type'),
        policies=pulumi.get(__response__, 'policies'),
        provider_config=pulumi.get(__response__, 'provider_config')))
